# Flashcards-eksempel

:::{flashcards}
:shuffle:
:show_progress:

Q: Hva er den deriverte av $x^2$?
A: $2x$

Q: Hva er arealet av en sirkel med radius $r$?
A: $A = \pi r^2$

Q: Hvilken likning beskriver Pythagoras' setning?
A: $a^2 + b^2 = c^2$
:::
